"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentViewer = exports.POLLING_INTERVAL = void 0;
const tslib_1 = require("tslib");
const client_utils_1 = require("@sensenet/client-utils");
const react_1 = tslib_1.__importDefault(require("react"));
const styled_components_1 = require("styled-components");
const loader_gif_1 = tslib_1.__importDefault(require("../../assets/loader.gif"));
const context_1 = require("../context");
const enums_1 = require("../enums");
const models_1 = require("../models");
const document_viewer_error_1 = require("./document-viewer-error");
const document_viewer_layout_1 = require("./document-viewer-layout");
const document_viewer_loading_1 = require("./document-viewer-loading");
const document_viewer_regenerate_previews_1 = require("./document-viewer-regenerate-previews");
exports.POLLING_INTERVAL = 5000;
const DocumentViewer = (props) => {
    return (react_1.default.createElement(context_1.DocumentViewerApiSettingsProvider, { options: props.api },
        react_1.default.createElement(context_1.LocalizationContext.Provider, { value: client_utils_1.deepMerge(context_1.defaultLocalization, props.localization) },
            react_1.default.createElement(context_1.ViewerSettingsContext.Provider, { value: props },
                react_1.default.createElement(styled_components_1.ThemeProvider, { theme: props.theme || models_1.defaultTheme },
                    react_1.default.createElement(context_1.DocumentDataProvider, null,
                        react_1.default.createElement(context_1.DocumentPermissionsContextProvider, null,
                            react_1.default.createElement(context_1.PreviewImageDataContextProvider, null,
                                react_1.default.createElement(context_1.DocumentDataContext.Consumer, null, ({ documentData }) => {
                                    if (documentData.pageCount === enums_1.PreviewState.Loading)
                                        return react_1.default.createElement(document_viewer_loading_1.DocumentViewerLoading, { image: props.loaderImage || loader_gif_1.default });
                                    if (documentData.pageCount === enums_1.PreviewState.Postponed) {
                                        return react_1.default.createElement(document_viewer_regenerate_previews_1.DocumentViewerRegeneratePreviews, null);
                                    }
                                    else if (documentData.pageCount < 0 || documentData.error) {
                                        return react_1.default.createElement(document_viewer_error_1.DocumentViewerError, null);
                                    }
                                    return (react_1.default.createElement(context_1.ViewerStateProvider, { options: props.defaultState },
                                        react_1.default.createElement(context_1.CommentStateProvider, null,
                                            react_1.default.createElement(context_1.CommentsContextProvider, null,
                                                react_1.default.createElement(document_viewer_layout_1.DocumentViewerLayout, null)))));
                                })))))))));
};
exports.DocumentViewer = DocumentViewer;
//# sourceMappingURL=document-viewer.js.map