"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SaveWidget = void 0;
const tslib_1 = require("tslib");
const IconButton_1 = tslib_1.__importDefault(require("@material-ui/core/IconButton"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const Save_1 = tslib_1.__importDefault(require("@material-ui/icons/Save"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../../hooks");
const useStyles = makeStyles_1.default(() => {
    return createStyles_1.default({
        iconButton: { display: 'inline-block' },
        icon: {},
    });
});
/**
 * Document widget component for saving document state
 */
const SaveWidget = (props) => {
    const classes = useStyles(props);
    const api = hooks_1.useDocumentViewerApi();
    const { documentData } = hooks_1.useDocumentData();
    const permissions = hooks_1.useDocumentPermissions();
    const pages = hooks_1.usePreviewImages();
    const viewerState = hooks_1.useViewerState();
    const localization = hooks_1.useLocalization();
    const save = react_1.useCallback(() => {
        permissions.canEdit &&
            api.saveChanges({
                document: documentData,
                pages: pages.imageData,
                abortController: new AbortController(),
            });
        viewerState.updateState({ hasChanges: false });
    }, [api, documentData, pages.imageData, permissions.canEdit, viewerState]);
    return (react_1.default.createElement(IconButton_1.default, { className: classes.iconButton, disabled: !viewerState.hasChanges || !permissions.canEdit, title: localization.saveChanges, onClick: save, id: "Save" },
        react_1.default.createElement(Save_1.default, { className: classes.icon })));
};
exports.SaveWidget = SaveWidget;
//# sourceMappingURL=save-widget.js.map