"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShapeAnnotation = void 0;
const tslib_1 = require("tslib");
const Button_1 = tslib_1.__importDefault(require("@material-ui/core/Button/Button"));
const Checkbox_1 = tslib_1.__importDefault(require("@material-ui/core/Checkbox/Checkbox"));
const ClickAwayListener_1 = tslib_1.__importDefault(require("@material-ui/core/ClickAwayListener/ClickAwayListener"));
const grey_1 = tslib_1.__importDefault(require("@material-ui/core/colors/grey"));
const Paper_1 = tslib_1.__importDefault(require("@material-ui/core/Paper/Paper"));
const Popper_1 = tslib_1.__importDefault(require("@material-ui/core/Popper/Popper"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const TextField_1 = tslib_1.__importDefault(require("@material-ui/core/TextField/TextField"));
const Delete_1 = tslib_1.__importDefault(require("@material-ui/icons/Delete"));
const react_1 = tslib_1.__importStar(require("react"));
const __1 = require("../..");
const hooks_1 = require("../../hooks");
const useStyles = makeStyles_1.default((theme) => {
    return createStyles_1.default({
        annotationInput: {
            width: '100%',
            height: '100%',
            overflow: 'auto',
            '&:focus': {
                outline: 'none',
            },
            writingMode: ({ rotationDegree }) => (rotationDegree === 0 || rotationDegree === 180 ? 'unset' : 'vertical-rl'),
            transform: ({ rotationDegree }) => (rotationDegree === 180 || rotationDegree === 270 ? 'rotate(180deg)' : 'none'),
        },
        title: {
            fontSize: '12px',
            marginRight: '6px',
        },
        textBox: {
            display: 'flex',
            justifyContent: 'space-between',
            alignItems: 'center',
            marginBottom: '6px',
        },
        textField: {
            width: '55px',
        },
        paper: {
            padding: '10px',
            marginLeft: '10px',
            border: `solid ${grey_1.default[600]} 2px`,
        },
        button: {
            backgroundColor: theme.palette.error.light,
        },
    });
});
const ShapeAnnotation = (props) => {
    var _a, _b;
    const viewerState = hooks_1.useViewerState();
    const rotationDegree = ((_b = (_a = viewerState.rotation) === null || _a === void 0 ? void 0 : _a.find((rotation) => rotation.pageNum === props.shape.imageIndex)) === null || _b === void 0 ? void 0 : _b.degree) || 0;
    const classes = useStyles({ rotationDegree });
    const localization = hooks_1.useLocalization();
    const permissions = __1.useDocumentPermissions();
    const [anchorEl, setAnchorEl] = react_1.useState(null);
    const open = Boolean(anchorEl);
    const id = open ? 'annotation-settings' : undefined;
    const getDimensions = () => {
        const dimensions = props.getShapeDimensions(props.shape);
        return { top: dimensions.top, left: dimensions.left, width: dimensions.width, height: dimensions.height };
    };
    const onRightClick = (event) => {
        event.preventDefault();
        setAnchorEl(anchorEl ? null : event.currentTarget);
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(__1.AnnotationWrapper, { shape: props.shape, zoomRatio: props.zoomRatio, dimensions: getDimensions(), onRightClick: onRightClick, onDragStart: props.onDragStart, onResized: props.onResized, rotationDegree: props.rotationDegree },
            react_1.default.createElement("div", { id: "annotation-input", className: classes.annotationInput, contentEditable: permissions.canEdit && rotationDegree === 0 ? 'plaintext-only' : false, suppressContentEditableWarning: true }, props.shape.text)),
        react_1.default.createElement(Popper_1.default, { id: id, open: open, anchorEl: anchorEl, placement: "right-start" },
            react_1.default.createElement(ClickAwayListener_1.default, { onClickAway: () => setAnchorEl(null) },
                react_1.default.createElement(Paper_1.default, { className: classes.paper },
                    react_1.default.createElement("div", { className: classes.textBox },
                        react_1.default.createElement("div", { className: classes.title }, "Line height:"),
                        react_1.default.createElement(TextField_1.default, { className: classes.textField, defaultValue: props.shape.lineHeight, size: "small", placeholder: "Line height", type: "number", onChange: (event) => props.updateShapeData('annotations', props.shape.guid, Object.assign(Object.assign({}, props.shape), { lineHeight: parseInt(event.target.value, 10) })) }),
                        react_1.default.createElement("div", { className: classes.title }, "px")),
                    react_1.default.createElement("div", { className: classes.textBox },
                        react_1.default.createElement("div", { className: classes.title }, "Font size:"),
                        react_1.default.createElement(TextField_1.default, { className: classes.textField, defaultValue: props.shape.fontSize, size: "small", placeholder: "Font size", type: "number", onChange: (event) => props.updateShapeData('annotations', props.shape.guid, Object.assign(Object.assign({}, props.shape), { fontSize: parseInt(event.target.value, 10) })) }),
                        react_1.default.createElement("div", { className: classes.title }, "px")),
                    react_1.default.createElement("div", { className: classes.textBox },
                        react_1.default.createElement("div", { className: classes.title }, "Font bold:"),
                        react_1.default.createElement(TextField_1.default, { className: classes.textField, defaultValue: props.shape.fontBold, size: "small", placeholder: "Font bold", type: "number", onChange: (event) => props.updateShapeData('annotations', props.shape.guid, Object.assign(Object.assign({}, props.shape), { fontBold: parseInt(event.target.value, 10) })) })),
                    react_1.default.createElement("div", { className: classes.textBox },
                        react_1.default.createElement("div", { className: classes.title }, "Font color:"),
                        react_1.default.createElement(TextField_1.default, { className: classes.textField, defaultValue: props.shape.fontColor, size: "small", placeholder: "Font color", type: "color", onChange: (event) => props.updateShapeData('annotations', props.shape.guid, Object.assign(Object.assign({}, props.shape), { fontColor: event.target.value })) })),
                    react_1.default.createElement("div", { className: classes.textBox },
                        react_1.default.createElement("div", { className: classes.title }, "Font italic:"),
                        react_1.default.createElement(Checkbox_1.default, { checked: props.shape.fontItalic, onChange: (event) => props.updateShapeData('annotations', props.shape.guid, Object.assign(Object.assign({}, props.shape), { fontItalic: event.target.checked })), name: "fontItalic", color: "primary" })),
                    react_1.default.createElement("div", { className: classes.textBox, style: { justifyContent: 'center' } },
                        react_1.default.createElement(Button_1.default, { variant: "contained", className: classes.button, onMouseUp: () => props.removeShape('annotations', props.shape.guid), startIcon: react_1.default.createElement(Delete_1.default, { scale: props.zoomRatio }) }, localization.delete)))))));
};
exports.ShapeAnnotation = ShapeAnnotation;
//# sourceMappingURL=shape-annotation.js.map