"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShapeRedaction = void 0;
const tslib_1 = require("tslib");
const Button_1 = tslib_1.__importDefault(require("@material-ui/core/Button/Button"));
const ClickAwayListener_1 = tslib_1.__importDefault(require("@material-ui/core/ClickAwayListener/ClickAwayListener"));
const Popper_1 = tslib_1.__importDefault(require("@material-ui/core/Popper/Popper"));
const createStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/createStyles"));
const makeStyles_1 = tslib_1.__importDefault(require("@material-ui/core/styles/makeStyles"));
const Delete_1 = tslib_1.__importDefault(require("@material-ui/icons/Delete"));
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../../hooks");
const useStyles = makeStyles_1.default((theme) => createStyles_1.default({
    root: {
        top: ({ dimensions }) => dimensions.top,
        left: ({ dimensions }) => dimensions.left,
        width: ({ dimensions }) => dimensions.width,
        height: ({ dimensions }) => dimensions.height,
        position: 'absolute',
        resize: ({ permissions, rotationDegree }) => (permissions.canEdit && rotationDegree === 0 ? 'both' : 'none'),
        overflow: 'auto',
        backgroundColor: 'black',
    },
    button: {
        backgroundColor: theme.palette.error.light,
    },
}));
/**
 * Return a styled redaction component
 * @param shape Shape attributes
 * @param permissions Permissions of the current user
 * @param dimensions Shape dimensions
 * @param zoomRatio Zoom ratio
 * @param onDragStart Function triggered on drag event
 * @param onResized Function triggered on resized event
 * @param removeShape Function triggered on delete
 * @returns styled redaction component
 */
function ShapeRedaction({ shape, permissions, dimensions, zoomRatio, onDragStart, onResized, removeShape, rotationDegree, }) {
    const classes = useStyles({
        shape,
        permissions,
        dimensions,
        zoomRatio,
        onDragStart,
        onResized,
        removeShape,
        rotationDegree,
    });
    const localization = hooks_1.useLocalization();
    const [anchorEl, setAnchorEl] = react_1.useState(null);
    const open = Boolean(anchorEl);
    const id = open ? 'redaction-delete' : undefined;
    const onRightClick = (event) => {
        event.preventDefault();
        setAnchorEl(anchorEl ? null : event.currentTarget);
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("div", { className: classes.root, tabIndex: 0, key: `r-${shape.h}-${shape.w}`, draggable: permissions.canEdit, onDragStart: onDragStart, onMouseUp: onResized, onContextMenu: onRightClick }),
        react_1.default.createElement(Popper_1.default, { id: id, open: open, anchorEl: anchorEl, placement: "right-start" },
            react_1.default.createElement(ClickAwayListener_1.default, { onClickAway: () => setAnchorEl(null) },
                react_1.default.createElement(Button_1.default, { variant: "contained", className: classes.button, onMouseUp: () => removeShape('redactions', shape.guid), startIcon: react_1.default.createElement(Delete_1.default, { scale: zoomRatio }) }, localization.delete)))));
}
exports.ShapeRedaction = ShapeRedaction;
//# sourceMappingURL=shape-redaction.js.map