"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@material-ui/core");
const react_1 = tslib_1.__importDefault(require("react"));
const useStyles = core_1.makeStyles(() => core_1.createStyles({
    root: {
        top: ({ dimensions }) => dimensions.top,
        left: ({ dimensions }) => dimensions.left,
        width: ({ dimensions }) => dimensions.width,
        height: ({ dimensions }) => dimensions.height,
        position: 'absolute',
        resize: ({ permissions }) => `${permissions.canEdit ? 'both' : 'none'}`,
        overflow: 'hidden',
        backgroundColor: 'blanchedalmond',
        lineHeight: ({ shape, zoomRatio }) => `${shape.lineHeight * zoomRatio}pt`,
        fontWeight: ({ shape }) => shape.fontBold,
        color: ({ shape }) => shape.fontColor,
        fontFamily: ({ shape }) => shape.fontFamily,
        fontSize: ({ shape, zoomRatio }) => parseFloat(shape.fontSize.replace('pt', '')) * zoomRatio,
        fontStyle: ({ shape }) => shape.fontItalic,
        boxShadow: ({ zoomRatio }) => `${5 * zoomRatio}px ${5 * zoomRatio}px ${15 * zoomRatio}px rgba(0,0,0,.3)`,
        padding: ({ zoomRatio }) => `${10 * zoomRatio}pt`,
        boxSizing: 'border-box',
    },
}));
/**
 * Retrun a styled wrapper component
 * @param permissions The permissions of the user
 * @param shape The arguments of the annotation
 * @param zoomRatio The arguments of the annotation
 * @param dimensions The dimensions of the annotation
 * @param children The wrapped components
 * @returns styled wrapper component
 */
function StyledWrapper({ permissions, shape, zoomRatio, dimensions, onDragStart, onResized, renderChildren, }) {
    const classes = useStyles({ permissions, shape, zoomRatio, dimensions, onDragStart, onResized, renderChildren });
    return (react_1.default.createElement("div", { className: classes.root, tabIndex: 0, draggable: permissions.canEdit, onDragStart: onDragStart, onMouseUp: onResized }, renderChildren()));
}
exports.default = StyledWrapper;
//# sourceMappingURL=styled-wrapper.js.map