"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentDataProvider = exports.DocumentDataContext = exports.defaultDocumentDataContextValue = void 0;
const tslib_1 = require("tslib");
const client_utils_1 = require("@sensenet/client-utils");
const hooks_react_1 = require("@sensenet/hooks-react");
const react_1 = tslib_1.__importStar(require("react"));
const semaphore_async_await_1 = tslib_1.__importDefault(require("semaphore-async-await"));
const components_1 = require("../components");
const enums_1 = require("../enums");
const hooks_1 = require("../hooks");
const defaultDocumentData = {
    documentName: '',
    documentType: '',
    fileSizekB: 0,
    hostName: '',
    idOrPath: 0,
    pageCount: enums_1.PreviewState.Loading,
    shapes: {
        annotations: [],
        highlights: [],
        redactions: [],
    },
    error: undefined,
};
exports.defaultDocumentDataContextValue = {
    documentData: defaultDocumentData,
    updateDocumentData: () => undefined,
    isInProgress: false,
    triggerReload: () => { },
};
exports.DocumentDataContext = react_1.default.createContext(exports.defaultDocumentDataContextValue);
const DocumentDataProvider = ({ children }) => {
    const api = hooks_1.useDocumentViewerApi();
    const doc = hooks_1.useViewerSettings();
    const repo = hooks_react_1.useRepository();
    const [documentData, setDocumentData] = react_1.useState(defaultDocumentData);
    const [loadLock] = react_1.useState(new semaphore_async_await_1.default(1));
    const [isInProgress, setIsInProgress] = react_1.useState(false);
    const [reloadToken, setReloadToken] = react_1.useState(0);
    const triggerReload = () => setReloadToken((prevValue) => prevValue + 1);
    react_1.useEffect(() => {
        const ac = new AbortController();
        const getData = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const result = yield api.getDocumentData({
                hostName: repo.configuration.repositoryUrl,
                idOrPath: doc.documentIdOrPath,
                version: doc.version,
                abortController: ac,
            });
            if (result.pageCount === enums_1.PreviewState.Loading) {
                setDocumentData(result);
                yield client_utils_1.sleepAsync(components_1.POLLING_INTERVAL);
                getData();
            }
            else {
                setDocumentData(result);
            }
        });
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                setIsInProgress(true);
                yield loadLock.acquire();
                yield getData();
            }
            catch (error) {
                if (!ac.signal.aborted) {
                    setDocumentData(Object.assign(Object.assign({}, defaultDocumentData), { pageCount: enums_1.PreviewState.ClientFailure, error: error.toString() }));
                    throw error;
                }
            }
            finally {
                setIsInProgress(false);
                loadLock.release();
            }
        }))();
        return () => ac.abort();
    }, [api, doc.documentIdOrPath, doc.version, loadLock, repo.configuration.repositoryUrl, reloadToken]);
    const updateDocumentData = react_1.useCallback((newDocData) => {
        const merged = client_utils_1.deepMerge(documentData, newDocData);
        if (JSON.stringify(documentData) !== JSON.stringify(merged)) {
            setDocumentData(merged);
        }
    }, [documentData]);
    if (!documentData.idOrPath) {
        return null;
    }
    return (react_1.default.createElement(exports.DocumentDataContext.Provider, { value: { documentData, updateDocumentData, isInProgress, triggerReload } }, children));
};
exports.DocumentDataProvider = DocumentDataProvider;
//# sourceMappingURL=document-data.js.map