"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentPermissionsContextProvider = exports.DocumentPermissionsContext = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../hooks");
exports.DocumentPermissionsContext = react_1.default.createContext({
    canEdit: false,
    canHideRedaction: false,
    canHideWatermark: false,
});
const DocumentPermissionsContextProvider = ({ children }) => {
    const { documentData } = hooks_1.useDocumentData();
    const api = hooks_1.useDocumentViewerApi();
    const [canEdit, setcanEdit] = react_1.useState(false);
    const [canHideRedaction, setcanHideRedaction] = react_1.useState(false);
    const [canHideWatermark, setcanHideWatermark] = react_1.useState(false);
    const documentIdOrPath = documentData.idOrPath;
    react_1.useEffect(() => {
        const abortController = new AbortController();
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                const canEditPromise = api.canEditDocument({ idOrPath: documentIdOrPath, abortController });
                const cancanHideRedactionPromise = api.canHideRedaction({ idOrPath: documentIdOrPath, abortController });
                const canHideWatermarkPromise = api.canHideWatermark({ idOrPath: documentIdOrPath, abortController });
                const [canEditValue, canHideRedactionValue, canHideWatermarkValue] = yield Promise.all([
                    canEditPromise,
                    cancanHideRedactionPromise,
                    canHideWatermarkPromise,
                ]);
                setcanEdit(canEditValue);
                setcanHideRedaction(canHideRedactionValue);
                setcanHideWatermark(canHideWatermarkValue);
            }
            catch (error) {
                if (!abortController.signal.aborted) {
                    throw error;
                }
            }
        }))();
    }, [api, documentIdOrPath]);
    return (react_1.default.createElement(exports.DocumentPermissionsContext.Provider, { value: {
            canEdit,
            canHideRedaction,
            canHideWatermark,
        } }, children));
};
exports.DocumentPermissionsContextProvider = DocumentPermissionsContextProvider;
//# sourceMappingURL=document-permissions.js.map