"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePreviewImage = void 0;
const tslib_1 = require("tslib");
const client_utils_1 = require("@sensenet/client-utils");
const react_1 = require("react");
const __1 = require("..");
const _1 = require(".");
const usePreviewImage = (pageNo) => {
    const api = _1.useDocumentViewerApi();
    const { documentData } = _1.useDocumentData();
    const viewerSettings = _1.useViewerSettings();
    const viewerState = _1.useViewerState();
    const { imageData, setImageData } = _1.usePreviewImages();
    const currentPageData = react_1.useMemo(() => imageData.find((i) => i.Index === pageNo), [imageData, pageNo]);
    react_1.useEffect(() => {
        const abortController = new AbortController();
        const getPreviewImageData = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                const previewImageData = yield api.isPreviewAvailable({
                    abortController,
                    document: documentData,
                    page: pageNo,
                    showWatermark: viewerState.showWatermark,
                    version: viewerSettings.version,
                });
                if (previewImageData === null || previewImageData === void 0 ? void 0 : previewImageData.PreviewAvailable) {
                    if (previewImageData.PreviewImageUrl) {
                        setImageData((previousValue) => {
                            const newImages = [...previousValue];
                            const oldValueIndex = newImages.findIndex((image) => image.Index === pageNo);
                            if (oldValueIndex !== -1) {
                                newImages[oldValueIndex] = Object.assign(Object.assign({}, previewImageData), { Index: pageNo });
                                return newImages;
                            }
                            else {
                                newImages.push(Object.assign(Object.assign({}, previewImageData), { Index: pageNo }));
                                return newImages;
                            }
                        });
                    }
                }
                else {
                    yield client_utils_1.sleepAsync(__1.POLLING_INTERVAL);
                    getPreviewImageData();
                }
            }
            catch (error) {
                if (!abortController.signal.aborted) {
                    throw error;
                }
            }
        });
        if (currentPageData && !currentPageData.PreviewImageUrl) {
            getPreviewImageData();
        }
        return () => abortController.abort();
    }, [api, currentPageData, documentData, pageNo, setImageData, viewerSettings.version, viewerState.showWatermark]);
    return {
        context: setImageData,
        image: currentPageData,
    };
};
exports.usePreviewImage = usePreviewImage;
//# sourceMappingURL=use-preview-image.js.map